@@ -1,6 +1,6 @@
 import re
 
-from IPython.display import display
+from IPython.display import Math, display
 
 from . import MagicGlobals as G
 
@@ -17,7 +17,9 @@ def latex_to_plain(latex_string: str) -> str:
 
     # assume latex string is raw string e.g. r'\text{ab c}'
 
-    pattern = re.compile(r"\\[a-zA-Z]+")  # latex commands like \text \rm
+    latex_string = latex_string.replace(r"\partial", "∂")
+
+    pattern = re.compile(r"\\([a-zA-Z]+|,)")  # latex commands like \text \rm and \,
 
     latex_string = re.sub(pattern, "", latex_string)
 
@@ -31,12 +33,15 @@ def show(*args):
     for x in args:
 
         if G.latex:
-            if hasattr(x, "display"):
-                display(x.display())
+            if hasattr(x, "latex_repr"):
+                display(Math(x.latex_repr))
             else:
                 display(x)
         else:
-            print(f"{x}\n")
+            if hasattr(x, "latex_repr"):
+                print(latex_to_plain(x.latex_repr))
+            else:
+                print(x)
 
 
 def latex_use_cdot():
